package com.lsf.cmd;

import java.awt.Color;
import java.awt.Font;

import javax.servlet.ServletOutputStream;

import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.CategoryLabelPositions;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.block.BlockBorder;
import org.jfree.chart.labels.ItemLabelAnchor;
import org.jfree.chart.labels.ItemLabelPosition;
import org.jfree.chart.labels.StandardCategoryItemLabelGenerator;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.renderer.category.AbstractCategoryItemRenderer;
import org.jfree.chart.renderer.category.BarRenderer3D;
import org.jfree.chart.renderer.category.LineAndShapeRenderer;
import org.jfree.ui.HorizontalAlignment;
import org.jfree.ui.TextAnchor;

public abstract class AbstractCategoryChartCmd extends AbstractChartCmd {
	protected void displayItemValue(AbstractCategoryItemRenderer renderer) {
		renderer
				.setBaseItemLabelGenerator(new StandardCategoryItemLabelGenerator());
		renderer.setItemLabelsVisible(true);

		ItemLabelPosition p = new ItemLabelPosition(ItemLabelAnchor.OUTSIDE1,
				TextAnchor.BOTTOM_CENTER);
		renderer.setPositiveItemLabelPosition(p);
		renderer.setItemLabelFont(new Font("batang",Font.BOLD,8));
		//   ÷ 
		renderer.setItemLabelPaint(new Color(100,0,0));

		renderer.setItemLabelAnchorOffset(5);

	}

	protected void createImage() throws Exception {
		res.setHeader("Cache-Control", "no-store");
		res.setHeader("Pragma", "no-cache");
		res.setDateHeader("Expires", 0);
		res.setContentType("image/jpeg");
		ServletOutputStream responseOutputStream = res.getOutputStream();
		// responseOutputStream.write(captchaChallengeAsJpeg);
		JFreeChart chart = createChart(createDataset());

		//chart.getTitle().setFont(new Font("dotum", Font.BOLD, 16));

		/* ʰ */
		chart.getLegend().setBackgroundPaint(Color.white);
		chart.getLegend().setBorder(BlockBorder.NONE);
		chart.getLegend().setHorizontalAlignment(HorizontalAlignment.RIGHT);
		//chart.getLegend().setItemFont(new Font("dotum",Font.PLAIN, 10));

		ChartUtilities.writeChartAsPNG(responseOutputStream, chart, width,
				height);
		responseOutputStream.flush();
		responseOutputStream.close();
	}

	protected void processBarChart(JFreeChart chart) {
		chart.setBackgroundPaint(Color.white);

		final CategoryPlot plot = chart.getCategoryPlot();

		final BarRenderer3D renderer = new BarRenderer3D();
		renderer.setDrawBarOutline(true);
		renderer.setOutlinePaint(Color.gray);

		//   ִ밪 
		renderer.setMaximumBarWidth(0.05);


		plot.setBackgroundPaint(new Color(240,240,240));
		plot.setDomainGridlinePaint(Color.red);
		plot.setRangeGridlinePaint(Color.white);


		/* vertical   аϱ */
		NumberAxis rangeAxis = (NumberAxis) plot.getRangeAxis();
		rangeAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
		rangeAxis.setUpperMargin(0.15);
		/* vertical   аϱ */

		/* Category X  ̱ */
		CategoryAxis domainAxis = plot.getDomainAxis();
		domainAxis.setCategoryLabelPositions(CategoryLabelPositions.DOWN_45);
		/* Category X  ̱ */

		displayItemValue(renderer);

		plot.setRenderer(renderer);
	}

	protected void processLineChart(JFreeChart chart) {
		chart.setBackgroundPaint(Color.white);

		final CategoryPlot plot = chart.getCategoryPlot();

		final LineAndShapeRenderer renderer = new LineAndShapeRenderer();
		renderer.setDrawOutlines(false);

		plot.setBackgroundPaint(new Color(240,240,240));
		plot.setDomainGridlinePaint(Color.red);
		plot.setRangeGridlinePaint(Color.white);

		// set the range axis to display integers only...
		/* vertical   аϱ */
		NumberAxis rangeAxis = (NumberAxis) plot.getRangeAxis();
		rangeAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
		rangeAxis.setUpperMargin(0.15);
		/* vertical   аϱ */

		/* Category X  ̱ */
		CategoryAxis domainAxis = plot.getDomainAxis();
		domainAxis.setCategoryLabelPositions(CategoryLabelPositions.UP_45);
		/* Category X  ̱ */

		displayItemValue(renderer);

		plot.setRenderer(renderer);
	}
}
